This is a simple Django app to easily and cleanly display Bootstrap Icons.

Install via pip install django-bs-icons

Add to settings.py apps 'bs_icons'

Simply add {% load bs_icons %} to the header section of your Django template.
Then add {% bs_icon 'NAME_OF_ICON' %}.

Here is the list of icons currently supported:

https://github.com/twbs/icons/tree/933852be6b67d1ec0adc782448f83305553b55d1/icons